@@ -29,7 +29,7 @@ _ZERO = re.compile("^0+$")
 def _is_old_octal(literal):
     if _ZERO.match(literal):
         return False
-    if re.match('0\d+', literal):
+    if re.match(r'0\d+', literal):
         try:
             int(literal, 8)
         except ValueError:
@@ -474,7 +474,7 @@ class Python3Checker(checkers.BaseChecker):
             'dircache', 'dl', 'exception', 'fpformat', 'htmllib', 'ihooks', 'imageop', 'imputil',
             'linuxaudiodev', 'md5', 'mhlib', 'mimetools', 'MimeWriter', 'mimify', 'multifile',
             'mutex', 'new', 'popen2', 'posixfile', 'pure', 'rexec', 'rfc822', 'sha', 'sgmllib',
-            'sre', 'stat', 'stringold', 'sunaudio', 'sv', 'test.testall', 'thread', 'timing',
+            'sre', 'stringold', 'sunaudio', 'sv', 'test.testall', 'thread', 'timing',
             'toaiff', 'user', 'urllib2', 'urlparse'
         ]),
         'deprecated-string-function': {
